object WritePersistence {

  def providerClass(provider: String) = {
    provider match {
      case "openjpa" =>
	<provider>org.apache.openjpa.persistence.PersistenceProviderImpl</provider>
      case "hibernate" =>
	<provider>org.hibernate.ejb.HibernatePersistence</provider>

      case _ =>
	<provider>org.eclipse.persistence.jpa.PersistenceProvider</provider>
    }
  }

  def providerProperties(provider: String) = {
    provider match {
      case "openjpa" =>
       <property name="openjpa.ConnectionURL"
                 value="jdbc:hsqldb:mem:test;create=true"/>
       <property name="openjpa.ConnectionDriverName"
                 value="org.hsqldb.jdbcDriver"/>
       <property name="openjpa.ConnectionUserName"  value="sa"/>

       <property name="openjpa.ConnectionPassword" value=""/>

      case "hibernate" =>
       <property name="hibernate.connection.driver_class"
                 value="org.hsqldb.jdbcDriver"/>
       <property name="hibernate.connection.url" value="jdbc:hsqldb:mem:test"/>
       <property name="hibernate.dialect"
	         value="org.hibernate.dialect.HSQLDialect"/>
       <property name="hibernate.hbm2ddl.auto" value="create-drop"/>
       <property name="hibernate.show_sql" value="true" /> 
       <property name="hibernate.connection.username" value="sa"/>
       <property name="hibernate.connection.password" value=""/>

      case _ =>
       <property name="eclipselink.jdbc.driver" value="org.hsqldb.jdbcDriver"/>
       <property name="eclipselink.jdbc.url" value="jdbc:hsqldb:mem:test"/>
       <property name="eclipselink.jdbc.user" value="sa"/>
       <property name="eclipselink.jdbc.password" value=""/>
       <property name="eclipselink.logging.level" value="SEVERE"/>
       <property name="eclipselink.create-ddl-jdbc-file-name" value="eclipselink-create.sql"/>
       <property name="eclipselink.ddl-generation"
                 value="drop-and-create-tables"/>
       <property name="eclipselink.target-database"
                 value="org.eclipse.persistence.platform.database.HSQLPlatform"/>
    }
  }

  def main(args: Array[String]) {
    val provider = if (args.length > 0) args(0) else "eclipselink"
    println(
<persistence xmlns="http://java.sun.com/xml/ns/persistence"
     xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
     xsi:schemaLocation="http://java.sun.com/xml/ns/persistence
     http://java.sun.com/xml/ns/persistence/persistence_1_0.xsd"
     version="1.0">
   <persistence-unit name="TestUnit" transaction-type="RESOURCE_LOCAL">
     <description>Unit for JPA Comparision Tests</description>
     { providerClass(provider) }
     <class>jpatest.Project</class>
     <class>jpatest.Project2</class>
     <class>jpatest.Milestone2</class>
     <class>jpatest.Project3</class>
     <class>jpatest.User3</class>
     <class>jpatest.Project4</class>
     <class>jpatest.User4</class>
     <class>jpatest.Role4</class>
     <exclude-unlisted-classes>false</exclude-unlisted-classes>
     <properties>
       { providerProperties(provider) }
    </properties>
  </persistence-unit>
</persistence>)
  }
}
